@@ -40,10 +40,12 @@ all(round(X[, 2] / X[, 1] - Y[, 2] / Y[, 1], 5) == 0)
 
 ## ---- fig.show = "hold"--------------------------------------------------
 pairs(X)
+
+## ---- fig.show = "hold"--------------------------------------------------
 pairs(Y)
 
 ## ---- warning = FALSE----------------------------------------------------
-cor(X)
+suppressWarnings(cor(X))
 cor(Y)
 
 ## ------------------------------------------------------------------------
@@ -52,6 +54,8 @@ propr:::proprVLR(X)
 
 ## ---- fig.show = "hold"--------------------------------------------------
 pairs(propr:::proprCLR(Y[, 1:4]))
+
+## ---- fig.show = "hold"--------------------------------------------------
 pairs(propr:::proprCLR(X))
 
 ## ------------------------------------------------------------------------
@@ -68,6 +72,8 @@ perb(Y)@matrix
 
 ## ---- fig.show = "hold"--------------------------------------------------
 pairs(propr:::proprALR(Y, ivar = 5))
+
+## ---- fig.show = "hold"--------------------------------------------------
 pairs(X[, 1:4])
 
 ## ------------------------------------------------------------------------
